@@ -34,8 +34,6 @@
 //
 //**********************************************************************
 
-#include <math.h>
-#include <float.h>
 #include "PolynomialRootFinder.h"
 
 //======================================================================
